@@ -21,9 +21,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "evolution-mapi-config.h"
 
 #include <glib/gi18n-lib.h>
 
@@ -79,7 +77,7 @@ e_cal_backend_mapi_events_factory_class_init (ECalBackendFactoryClass *class)
 	backend_factory_class->share_subprocess = TRUE;
 
 	class->factory_name = FACTORY_NAME;
-	class->component_kind = ICAL_VEVENT_COMPONENT;
+	class->component_kind = I_CAL_VEVENT_COMPONENT;
 	class->backend_type = E_TYPE_CAL_BACKEND_MAPI;
 }
 
@@ -103,7 +101,7 @@ e_cal_backend_mapi_journal_factory_class_init (ECalBackendFactoryClass *class)
 	backend_factory_class->share_subprocess = TRUE;
 
 	class->factory_name = FACTORY_NAME;
-	class->component_kind = ICAL_VJOURNAL_COMPONENT;
+	class->component_kind = I_CAL_VJOURNAL_COMPONENT;
 	class->backend_type = E_TYPE_CAL_BACKEND_MAPI;
 }
 
@@ -127,7 +125,7 @@ e_cal_backend_mapi_todos_factory_class_init (ECalBackendFactoryClass *class)
 	backend_factory_class->share_subprocess = TRUE;
 
 	class->factory_name = FACTORY_NAME;
-	class->component_kind = ICAL_VTODO_COMPONENT;
+	class->component_kind = I_CAL_VTODO_COMPONENT;
 	class->backend_type = E_TYPE_CAL_BACKEND_MAPI;
 }
 
